;****************************************************************************************
;*                           STOP-SCHALTUHR                                             *
;*                           ==============                                             *
;*                                                                                      *
;*--------------------------------------------------------------------------------------*
;* PORT-PIN-ZUORDNUNG:                                                                  *
;* RA0 -EINGANG ABWAERTS ZAEHLEN                                                        *
;* RA1 -EINGANG AUFWAERTS ZAEHLEN                                                       *
;* RA2 -AUSGANG DATEN/BEFEHL LCD-MODUL                                                  *
;* RA3 -AUSGANG ENABLE LCD-MODUL                                                        *
;* RA4 -EINGANG START / STOP                                                            *
;* RA5 -EINGANG UNBENUTZT                                                               *
;* RA6 =OZS2 4MHZ QUARZ                                                                 *
;* RA7 =OZS1 4MHZ QUARZ                                                                 *
;*                                                                                      *
;* RB0 -AUSGANG HEIZUNG                                                                 *
;* RB1 -AUSGANG KONTROLL-LED                                                            *
;* RB2 -AUSGANG ENDE-HUPE                                                               *
;* RB3 -EINGANG UNBENUTZT                                                               *
;* RB4 -AUSGANG LCD-MODUL   ALLES DATENBUS 4-BIT                                        *
;* RB5 -AUSGANG LCD-MODUL                                                               *
;* RB6 -AUSGANG LCD-MODUL                                                               *
;* RB7 -AUSGANG LCD-MODUL                                                               *
;*                                                                                      *
;* RA5 GEHT NUR ALS EINGANG WEGEN DEM ICSP-PROGRAMMIEREN                                *
;*                                                                                      *
;*--------------------------------------------------------------------------------------*
;*--------------------------------------------------------------------------------------*
;*                                                                                      *
;* ALS PIC-IC WURDE GENOMMEN PIC16F628A                                                 *
;* ALS OSZILLATOR WURDE EIN QUARZ MIT 4,00MHZ GENOMMEN. (T=0.250SEC ALSO DIE TAKTZEIT) *
;*                                   EIN BEFEHL HAT MEIST 4 TAKTE SIND 1,0SEC          *
;*                                                                                      *
;*--------------------------------------------------------------------------------------*
;*                           BEGINN: 29.11.14                                           *
;*                           ENDE  : 04.12.14                                           *
;*                         GETESTET: 04.12.14                                           *
;****************************************************************************************

        LIST    P=16F628A       
        TITLE   "UHR-HOCH"

        ERRORLEVEL -302
        INCLUDE <P16F628A.INC>

__CONFIG   _XT_OSC & _WDT_OFF & _PWRTE_OFF & _BODEN_OFF & _MCLRE_OFF & _LVP_OFF & _DATA_CP_OFF & _CP_OFF

;--------------------------------------------------------------------------
;REGISTER ZUORDNEN NACH DEM DIE FESTEN-REGISTER ZU ENDE SIND
;ES GEHT ALSO ERST AB 22 HEX LOS
;DIES IST ALSO DIE RAM-SPEICHER ZUORDNUNG


HELP1                   EQU     0X22    ;HILFSZELLE
HELP2                   EQU     0X23    ;HILFSZELLE
BIT                     EQU     0X24    ;HILFSZELLE FR DIE LCD-BCD-ANZEIGE 4-BIT 
MIN                     EQU     0X25
SEC                     EQU     0X26
DOPPEL                  EQU     0X27    ;DOPPELPUNKT BLINKT
MIN_E                   EQU     0X28    ;EINSTELLZEIT
SEC_E                   EQU     0X29    ;EINSTELLZEIT
MERK                    EQU     0X2A    ;BEFEHL+DATEN HILFSZELLE
MERK1                   EQU     0X2B    ;REPEAT MERKER BIT0
ZAE                     EQU     0X2C    ;REPEAT SCHNELLER

;--------------------------- VARIABLEN -------------------------------------
BIT7                    EQU     7       ; BIT 7
BIT6                    EQU     6       ; BIT 6
BIT5                    EQU     5       ; BIT 5
BIT4                    EQU     4       ; BIT 4
BIT3                    EQU     3       ; BIT 3 
BIT2                    EQU     2       ; BIT 2
BIT1                    EQU     1       ; BIT 1 
BIT0                    EQU     0       ; BIT 0

;======================= FUER LCD-MODUL ===========================
RS                      EQU     2       ; PORTA BIT2 UMSCHALTEN BEFEHL/DATEN      BEI WRITE DATEN IST ES HIGH
EN                      EQU     3       ; PORTA BIT3 ENABLE FALLENDE FLANKE
;==================================================================
;======================= FUER TASTER ==============================
START                   EQU     4       ; PORTA BIT4 START+STOP-TASTER
AUF                     EQU     1       ; PORTA BIT1 AUFWRTS STELLEN
AB                      EQU     0       ; PORTA BIT0 ABWRTS STELLEN
;======================= FUER AUSGNGE =============================
HEIZ                    EQU     0       ; PORTB BIT0 HEIZUNG
KONT                    EQU     1       ; PORTB BIT1 KONTROLL-LED
HUPE                    EQU     2       ; PORTB BIT2 HUPE

;------------------------- MACROS -----------------------------------------

BANK0           MACRO                   ;MACRO TO SELECT DATA RAM BANK 0
                BCF     STATUS,RP0
                BCF     STATUS,RP1
                ENDM

BANK1           MACRO                   ;MACRO TO SELECT DATA RAM BANK 1
                BSF     STATUS,RP0
                BCF     STATUS,RP1
                ENDM

BANK2           MACRO                   ;MACRO TO SELECT DATA RAM BANK 2
                BCF     STATUS,RP0
                BSF     STATUS,RP1
                ENDM

BANK3           MACRO                   ;MACRO TO SELECT DATA RAM BANK 3
                BSF     STATUS,RP0
                BSF     STATUS,RP1
                ENDM

 
;-----------------------------------------------------------------------------
;SPEICHERANFANG BZW. BEGINN

                ORG 0X0000
                GOTO MAIN               ; SPRUNG ZUM HAUPTPROGRAMM
                ORG 0X0004
                RETFIE                  ; BEI EINEM INTERRUPT SOFORT EIN RETURN

                ORG 0X0010

;*****************************************************************************
;*                            HAUPTPROGRAMM                                  *
;*                              01.02.11                                     *
;*****************************************************************************
;PORT-INITIALISIERUNG
MAIN            CLRF    PORTA                           
                CLRF    PORTB
                MOVLW   0X07                    ;COMPARATORS ALLE AUS VOM PORT A
                MOVWF   CMCON
                BANK1
                MOVLW   B'11110011'             ;INIT INPUT/OUTPUT AM PORTA --> BEI 0 AUSGAENGE -->RA2+3 AUSGANG SONST EINGANG
                MOVWF   TRISA
                MOVLW   B'00001000'             ;INIT I/O PORTB VON RB0 BIS RB2 AUSGNGE / RB4 BIS R7 DATENBUS FR ANZEIGE / NUR RB3 ALS EINGANG 
                MOVWF   TRISB

;INIT TIMER 0 
                MOVLW   B'10000111'             ;BIT0-2 1=PRESCALER256, BIT3 0=TMR0, BIT4 0=ENTFAELLT, BIT5 0=TAKT VOM SYSTEM, BIT6 0=KEIN RB-INTERRUPT, BIT7 1=PULL-UPS DISABLE 
                MOVWF   OPTION_REG      
                BANK0

;INIT TIMER1
                MOVLW   0X30                ;PRESCALE1:8 / SYSTEMCLOCK T/4 ==>1/32
                MOVWF   T1CON               

;GRUNDEINSTELLUNGEN
                CLRF    PORTA
                CLRF    PORTB

;50MSEC ZEITSCHLEIFE
                MOVLW   D'50'                 ;ZEITSCHLEIFE LADEN IN W MIT DEZIMAL 50 ALSO---> 50*1MSEC=50MSEC
                CALL    ZS1MS                 ;ZEITSCHLEIFE ABARBEITEN

;INITIALISIERUNG DOT-MATRIX-LCD
                MOVLW   H'28'                 ;FUNCTION SET  4-BIT-LAENGE, 2-ZEILIG, 5X7FONT
                CALL    BEFEHL

                MOVLW   H'0C'                 ;DISPLAY ON/OFF   DISPLAY ON, CURSOR OFF, BLINK OFF
                CALL    BEFEHL

                MOVLW   H'01'                 ;CLEAR DISPLAY
                CALL    BEFEHL

;5MSEC ZEITSCHLEIFE
                MOVLW   D'5'                 ;ZEITSCHLEIFE LADEN IN W MIT DEZIMAL 5 ALSO---> 5*1MSEC=5MSEC
                CALL    ZS1MS                ;ZEITSCHLEIFE ABARBEITEN

;---------------INITIALISIERUNG--ZU--ENDE-----------------------
            
;------------
ANFANG
;------------
            CALL    GEHT                    ;TEXT AUF LCD-ANZEIGE "GEHT GLEICH LOS" MIT INTERNER ZEITSCHLEIFE 5SEC

ANFY        CALL    EINST                   ;TEXT
            CALL    ZEIT                    ;TEXT

;EEPROM AUSLESEN / LETZTE ZEIT
            MOVLW   H'00'
            CALL    E_READ
;MIN STELLZEIT WAR IN W
            MOVWF   MIN_E
            MOVWF   MIN

;EEPROM AUSLESEN / LETZTE ZEIT
            MOVLW   H'01'
            CALL    E_READ
;MIN STELLZEIT WAR IN W
            MOVWF   SEC_E
            MOVWF   SEC

            CALL    ANZEIGE                 ;EINSTELLZEIT ANZEIGEN 

            CALL    AUFAB                   ;STELLEN AUF UND AB EINSTELLZEIT
            CALL    E_WRITE

;START
WEIT1               MOVLW   D'20'           ;ENTPRELLUNG 20MSEC, UM ZU STARTEN DIE BACKUHR
                    MOVWF   HELP2
WEIT2               BTFSC   PORTA, START
                    GOTO    WEIT1
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    WEIT2

;DAS LOSLASSEN VON START, DANN GEHT ES ERST LOS
WEIT3               MOVLW   D'20'           ;ENTPRELLUNG 20MSEC, UM ZU STARTEN DIE BACKUHR
                    MOVWF   HELP2
WEIT4               BTFSS   PORTA, START
                    GOTO    WEIT3
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    WEIT4

            CALL    BACK                    ;TEXT
            CALL    EIN
;----------
;BACKUHR GEHT AB 0 MIN : 00SEC LOS
            CALL    UHR
;----------
            CALL    ENDE                    ;TEXT
            CALL    AUS
;----------
;ES GEHT ZU NEUEM PRODUKT BACKEN
WEIT11              BTFSS   PORTA, AUF
                    GOTO    WEITA
                    BTFSS   PORTA, AB
                    GOTO    WEITC
                    GOTO    WEIT11
;GEDRCKT AUF-TASTER
WEITA               MOVLW   D'40'           ;ENTPRELLUNG 40MSEC, 
                    MOVWF   HELP2
WEITB               BTFSC   PORTA, AUF
                    GOTO    WEIT11
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    WEITB
;LOSLASSEN AUF-TASTER
WEITAA              MOVLW   D'40'           ;ENTPRELLUNG 40MSEC, 
                    MOVWF   HELP2
WEITBB              BTFSS   PORTA, AUF
                    GOTO    WEITAA
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    WEITBB

                    GOTO    ANFY


;GEDRCKT AB-TASTER
WEITC               MOVLW   D'40'           ;ENTPRELLUNG 40MSEC, 
                    MOVWF   HELP2
WEITD               BTFSC   PORTA, AB
                    GOTO    WEIT11
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    WEITD
;LOSLASSEN AB-TASTER
WEITCC              MOVLW   D'40'           ;ENTPRELLUNG 40MSEC, 
                    MOVWF   HELP2
WEITDD              BTFSS   PORTA, AB
                    GOTO    WEITCC
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    WEITDD

                    GOTO    ANFY
;*****************************************************************************
;*                              EIN                                          *
;*                                                                           *
;*****************************************************************************
EIN                 BSF     PORTB, KONT
                    BSF     PORTB, HEIZ
                    BCF     PORTB, HUPE
                    RETURN


;*****************************************************************************
;*                              AUS                                          *
;*                                                                           *
;*****************************************************************************
AUS                 BCF     PORTB, KONT
                    BCF     PORTB, HEIZ

                    BSF     PORTB, HUPE      ;HUPE EIN
                    MOVLW   D'50'            ;FR 5SEC HUPE
                    CALL    ZS100MS          ;ES GILT 50 * 100MSEC = 5000MSEC =5SEC
                    BCF     PORTB, HUPE      ;HUPE AUS
                    RETURN


;*****************************************************************************
;*                              EEPROM WRITE                                 *
;*                              17.12.08                                     *
;*****************************************************************************
E_WRITE         BCF     PIR1, EEIF
                MOVF    MIN, W                  ;MIN IST ZU SPEICHERNDES BYTE  ;ADRESSE UND DATEN LADEN, WELCHE GESPEICHERT WERDEN SOLLEN
                BANK1
                MOVWF   EEDATA
                BANK0
                MOVLW   0X00                    ;EEPROM-ADRESSE
                BANK1
                MOVWF   EEADR

                BSF     EECON1, WREN
                MOVLW   0X55
                MOVWF   EECON2
                MOVLW   0XAA
                MOVWF   EECON2
                BSF     EECON1, WR
W_1             BTFSC   EECON1, WR
                GOTO    W_1
                BSF     EECON1, WREN
                BANK0

;-------------
                BCF     PIR1, EEIF
                MOVF    SEC, W                  ;SEC IST ZU SPEICHERNDES BYTE  ;ADRESSE UND DATEN LADEN, WELCHE GESPEICHERT WERDEN SOLLEN
                BANK1
                MOVWF   EEDATA
                BANK0
                MOVLW   0X01                    ;EEPROM-ADRESSE
                BANK1
                MOVWF   EEADR

                BSF     EECON1, WREN
                MOVLW   0X55
                MOVWF   EECON2
                MOVLW   0XAA
                MOVWF   EECON2
                BSF     EECON1, WR
W_2             BTFSC   EECON1, WR
                GOTO    W_2
                BSF     EECON1, WREN
                BANK0
                BCF     PIR1, EEIF


                RETURN
;DIE EEPROMADRESSE MUSS IN ADR STEHEN
;DAS ZU SPEICHERNDE BYTE IN MIN

;*****************************************************************************
;*                              EEPROM READ                                  *
;*                              16.12.08                                     *
;*****************************************************************************
E_READ          BANK1
                MOVWF   EEADR
                BSF     EECON1, RD
EE1             BTFSC   EECON1, RD
                GOTO    EE1
                MOVF    EEDATA, W
                BANK0
                        MOVWF   HELP1

                        SUBLW   H'FF'                ;WAR NOCH NICHTS GESPEICHERT BEIM 1-TEN START
                        BTFSS   STATUS, Z
                        GOTO    EEE1

                MOVLW   H'40'
                RETURN


EEE1            MOVF    HELP1, W
                RETURN
;AM ANFANG MUSS W MIT DER EEPROM-ADRESSE GELADEN SEIN
;DAS ERGEBNIS DES WERTES VOM EEPROM-INHALT STEHT AM ENDE IN W

;*****************************************************************************
;*         UNTERPROGRAMM AUF+AB STELLEN                                      *
;*                                                                           *
;*****************************************************************************
AUFAB               MOVLW   D'50'
                    MOVWF   ZAE

                    BTFSS   PORTA, AUF
                    GOTO    EITA
                    BTFSS   PORTA, AB
                    GOTO    EITC
                    BTFSC   PORTA, START
                    GOTO    AUFAB

;GEDRCKT START-TASTER / BACKEN STARTEN
ITA                 MOVLW   D'20'           ;ENTPRELLUNG 20MSEC, 
                    MOVWF   HELP2
ITB                 BTFSC   PORTA, START
                    GOTO    AUFAB
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    ITB

            MOVF    MIN_E, W
            MOVWF   MIN

                    RETURN

;-------------------------------------------------------------------
;GEDRCKT AUF-TASTER
EITA                MOVLW   D'40'          ;ENTPRELLUNG 40MSEC, 
                    MOVWF   HELP2
EITB                BTFSC   PORTA, AUF
                    GOTO    AUFAB
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    EITB

;REPEAT
RPAUF               MOVF    ZAE, W         ;ENTPRELLUNG 600MSEC, 
                    MOVWF   HELP2
TB                  BTFSC   PORTA, AUF
                    GOTO    EITAA
                    MOVLW   D'3'
                    CALL    ZS1MS          ;10MSEC
                    DECFSZ  HELP2, F
                    GOTO    TB

                    DECF    ZAE, F
                        MOVLW   H'01'                ;NICHT NIEDRIGER ZHLEN
                        SUBWF   ZAE, W
                        BTFSC   STATUS, Z
                        INCF    ZAE, F

                    BSF     MERK1, BIT0     ;REPEAT MERKER
                    GOTO    WW1

;LOSLASSEN AUF-TASTER
EITAA               MOVLW   D'40'           ;ENTPRELLUNG 40MSEC, 
                    MOVWF   HELP2
EITBB               BTFSS   PORTA, AUF
                    GOTO    EITAA
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    EITBB

                    BTFSS   MERK1, BIT0     ;REPEAT MERKER
                    GOTO    WW1
                    CLRF    MERK1
                    GOTO    AUFAB

WW1                     MOVLW   H'99'                ;BEI MIN NICHT BERSCHREITEN BEI AUFWRTS
                        SUBWF   MIN_E, W
                        BTFSC   STATUS, Z
                        GOTO    EIT0

                    INCF    SEC_E, F        ;UM 1 ERHHEN BEI EINZELDRUCK MIT LOSLASSEN

                        MOVF    SEC_E, W
                        ANDLW   0X0F
                        MOVWF   HELP2

                        MOVLW   0X0A                ;ALLER 10SEC
                        SUBWF   HELP2, W
                        BTFSS   STATUS, Z
                        GOTO    EIT0
                        MOVF    SEC_E, W
                        ANDLW   0XF0
                        ADDLW   0X10
                        MOVWF   SEC_E

                        MOVLW   H'60'                ;BEI SEC ERREICHT STELLE +1MIN
                        SUBWF   SEC_E, W
                        BTFSS   STATUS, Z
                        GOTO    EIT0

                    MOVLW   H'00'
                    MOVWF   SEC_E
                    INCF     MIN_E, F

                        MOVF    MIN_E, W
                        ANDLW   0X0F
                        MOVWF   HELP2

                        MOVLW   0X0A                ;ALLER 10MIN
                        SUBWF   HELP2, W
                        BTFSS   STATUS, Z
                        GOTO    EIT0
                        MOVF    MIN_E, W
                        ANDLW   0XF0
                        ADDLW   0X10
                        MOVWF   MIN_E


EIT0        MOVF    MIN_E, W
            MOVWF   MIN

            MOVF    SEC_E, W
            MOVWF   SEC

                    CALL    ANZEIGE 

                    BTFSC   MERK1, BIT0
                    GOTO    RPAUF
                    GOTO    AUFAB


;GEDRCKT AB-TASTER
EITC                MOVLW   D'40'           ;ENTPRELLUNG 40MSEC, 
                    MOVWF   HELP2
EITD                BTFSC   PORTA, AB
                    GOTO    AUFAB
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    EITD

;REPEAT
RPAB                MOVF    ZAE, W          ;ENTPRELLUNG 600MSEC, 
                    MOVWF   HELP2
TBW                 BTFSC   PORTA, AB
                    GOTO    EITCC
                    MOVLW   D'3'
                    CALL    ZS1MS          ;10MSEC
                    DECFSZ  HELP2, F
                    GOTO    TBW

                    DECF    ZAE, F
                        MOVLW   H'01'                ;NICHT NIEDRIGER ZHLEN
                        SUBWF   ZAE, W
                        BTFSC   STATUS, Z
                        INCF    ZAE, F

                    BSF     MERK1, BIT0     ;REPEAT MERKER
                    GOTO    WW2

;LOSLASSEN AB-TASTER
EITCC               MOVLW   D'40'           ;ENTPRELLUNG 40MSEC, 
                    MOVWF   HELP2
EITDD               BTFSS   PORTA, AB
                    GOTO    EITCC
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    EITDD

                    BTFSS   MERK1, BIT0     ;REPEAT MERKER
                    GOTO    WW2
                    CLRF    MERK1
                    GOTO    AUFAB

WW2                     MOVLW   H'01'                ;BEI SEC NICHT UNTERSCHREITEN BEI ABWRTS
                        SUBWF   SEC_E, W
                        BTFSS   STATUS, Z
                        GOTO    TT1
                        MOVLW   H'00'                ;UND BEI MIN NICHT UNTERSCHREITEN BEI ABWRTS
                        SUBWF   MIN_E, W
                        BTFSC   STATUS, Z
                        GOTO    EIT1

TT1                 DECF    SEC_E, F        ;UM 1 ERNIEDRIGEN BEI EINZELDRUCK MIT LOSLASSEN

                        MOVF    SEC_E, W
                        ANDLW   0X0F
                        MOVWF   HELP2

                        MOVLW   0X0F                
                        SUBWF   HELP2, W
                        BTFSS   STATUS, Z
                        GOTO    EIT1
                        MOVLW   D'6'
                        SUBWF   SEC_E, F

                        MOVLW   H'F9'                ;BEI SEC ERREICHT STELLE MIN-1
                        SUBWF   SEC_E, W
                        BTFSS   STATUS, Z
                        GOTO    EIT1

                    MOVLW   H'59'
                    MOVWF   SEC_E
                    DECF    MIN_E, F        ;UM 1 ERNIEDRIGEN BEI EINZELDRUCK MIT LOSLASSEN

                        MOVF    MIN_E, W
                        ANDLW   0X0F
                        MOVWF   HELP2

                        MOVLW   0X0F                
                        SUBWF   HELP2, W
                        BTFSS   STATUS, Z
                        GOTO    EIT1
                        MOVLW   D'6'
                        SUBWF   MIN_E, F


EIT1        MOVF    MIN_E, W
            MOVWF   MIN

            MOVF    SEC_E, W
            MOVWF   SEC

                    CALL    ANZEIGE

                    BTFSC   MERK1, BIT0
                    GOTO    RPAB

                    GOTO    AUFAB



;*****************************************************************************
;*         UNTERPROGRAMM UHR                                                 *
;*                                                                           *
;*****************************************************************************
UHR                     CALL    I_ZS500MS

                        CLRF    MIN
                        CLRF    SEC


U1                      MOVLW   D'2'
                        MOVWF   DOPPEL

                        CALL    ANZEIGE

;-------
;FRAGEN OB MIN-SEC-STELLZEIT ERREICHT IST
                    MOVF    MIN, W
                    SUBWF   MIN_E, W
                    BTFSS   STATUS, Z
                    GOTO    U2

                    MOVF    SEC, W
                    SUBWF   SEC_E, W
                    BTFSS   STATUS, Z
                    GOTO    U2
                    BCF     T1CON, TMR1ON  ;STOP TIMER1
                    RETURN
                        

U2                      BTFSC   PIR1, TMR1IF        ;OVERFLOW KONTROLLIEREN BEI 500MSEC
                        GOTO    U22
                        BTFSC   PORTA, START        ;HIER STOP
                        GOTO    U2


U3                  MOVLW   D'40'          ;ENTPRELLUNG 40MSEC, UM ZU STARTEN DIE BACKUHR
                    MOVWF   HELP2
WEIT5               BTFSC   PORTA, START   ;HIER STOP
                    GOTO    U2
                    MOVLW   D'1'
                    CALL    ZS1MS          ;1MSEC
                    DECFSZ  HELP2, F
                    GOTO    WEIT5
                    BCF     T1CON, TMR1ON  ;STOP TIMER1
                    RETURN

U22                     CALL    I_ZS500MS
                        DECFSZ  DOPPEL, F
                        GOTO    UA

                        MOVLW   H'C8'               ;DOPPELPUNKT BLINKT IN 0,5SEC
                        CALL    BEFEHL
                        MOVLW   ":"
                        CALL    DATEN
                        GOTO    UB

UA                      MOVLW   H'C8'               ;DOPPELPUNKT BLINKT IN 0,5SEC
                        CALL    BEFEHL
                        MOVLW   " "
                        CALL    DATEN
                        GOTO    U2

;-----------
;STELLE UHR
UB                      INCF    SEC, F

                        MOVF    SEC, W
                        ANDLW   0X0F
                        MOVWF   HELP1

                        MOVLW   0X0A                ;BEI 10SEC
                        SUBWF   HELP1, W
                        BTFSS   STATUS, Z
                        GOTO    U1
                        MOVF    SEC, W
                        ANDLW   0XF0
                        ADDLW   0X10
                        MOVWF   SEC

                        MOVLW   0X60                ;BEI 60SEC  MACHE +1MIN
                        SUBWF   SEC, W
                        BTFSS   STATUS, Z
                        GOTO    U1

                        INCF    MIN, F
                        CLRF    SEC

                        MOVF    MIN, W
                        ANDLW   0X0F
                        MOVWF   HELP1

                        MOVLW   0X0A                ;ALLER 10MIN
                        SUBWF   HELP1, W
                        BTFSS   STATUS, Z
                        GOTO    U1
                        MOVF    MIN, W
                        ANDLW   0XF0
                        ADDLW   0X10
                        MOVWF   MIN

                        GOTO    U1    

;*****************************************************************************
;*         UNTERPROGRAMM BCD ANZEIGE                                         *
;*                                                                           *
;*****************************************************************************
ANZEIGE

;MIN EINERSTELLE
                        MOVLW   H'C2' 
                        CALL    BEFEHL

                        MOVF    MIN, W
                        ANDLW   0X0F
                        ADDLW   0X30
                        CALL    DATEN

;MIN ZEHNERSTELLE
                        MOVLW   H'C1' 
                        CALL    BEFEHL

                        MOVF    MIN, W
                        MOVWF   HELP1
                        RRF     HELP1, F
                        RRF     HELP1, F
                        RRF     HELP1, F
                        RRF     HELP1, F

                        MOVF    HELP1, W
                        ANDLW   0X0F
                        MOVWF   HELP1

                        SUBLW   0X00            ;VORNULL AUSBLENDEN
                        BTFSC   STATUS, Z
                        GOTO    ANZ2

                        MOVF    HELP1, W                        
                        ADDLW   0X30
                        CALL    DATEN
                        GOTO    ANZ1

ANZ2                    MOVLW   " "
                        CALL    DATEN

;--------------------------
;SEC EINERSTELLE
ANZ1                    MOVLW   H'CB' 
                        CALL    BEFEHL

                        MOVF    SEC, W
                        ANDLW   0X0F
                        ADDLW   0X30
                        CALL    DATEN

;SEC ZEHENERSTELLE
                        MOVLW   H'CA' 
                        CALL    BEFEHL

                        MOVF    SEC, W
                        MOVWF   HELP1
                        RRF     HELP1, F
                        RRF     HELP1, F
                        RRF     HELP1, F
                        RRF     HELP1, F

                        MOVF    HELP1, W
                        ANDLW   0X0F
                        
                        ADDLW   0X30
                        CALL    DATEN

                        RETURN

;*****************************************************************************
;*         UNTERPROGRAMM MIT TIMER0 ALS ZEITSCHLEIFE FUER  1MSEC ....        *
;*                                                                           *
;*****************************************************************************
ZS1MS                   MOVWF   HELP1                   ;DER INHALT VON W WIRD IN "HELP1" GELADEN

T01                     MOVLW   D'252'
                        MOVWF   TMR0                    ;DER FESTE RAM-SPEICHER (TMR0) WIRD MIT 252 GELADEN
                        BCF     INTCON, T0IF            ;OVERFLOW = 0
                
T02                     BTFSS   INTCON, T0IF            ;WENN DIE ZEIT VON 10MSEC ABGELAUFEN IST, WIRD T0IF HIGH (1) UND 
                        GOTO    T02                     ;ES ERFOLGT EIN SPRUNG ZU "DECFSC MERK, F"
                        
                        DECFSZ  HELP1, F                ;ES WIRD DER WERT IN "HELP1" ABWRTS GEZHLT, BIS ER (0) IST UND
                        GOTO    T01                     ;DANN ERFOLGT EIN SPRUNG ZU "RETURN"-ENDE DES UNTERPROGRAMMS
                        RETURN

;ZEITBERECHNUNG FUER 1MS
;PRESCALER 256X  *  SYSTEM 4X  * TAKTZEIT ====> 256*4*0.250SEC=256SEC    /DIE TAKTZEIT ERGIBT SICH AUS DEM INTERNEN OSZILLATOR
;1MS : 256SEC= 3,9 GENOMMEN 4                                             /T = 1 : F  (F)-OSZILLATORFREQUENZ
;ALSO
;256S*D'4'=1,024MSEC
;TMR0 ALSO D'256'-D'4'=D'252' ENTSPRICHT CA. 1MS
;252 DEZIMAL OBEN EINTRAGEN

;*****************************************************************************
;*         UNTERPROGRAMM MIT TIMER0 ALS ZEITSCHLEIFE FUER  100MSEC ....      *
;*                                                                           *
;*****************************************************************************
ZS100MS                 MOVWF   HELP1                   ;DER INHALT VON W WIRD IN "HELP1" GELADEN

T100                    MOVLW   D'2'                    ;2MAL WIRD DIE 1MSEC ZEIT ABGEARBEITET, HIER WIRD GELADEN
                        MOVWF   HELP2                   ;ALSO 100MSEC

T101                    MOVLW   D'61'
                        MOVWF   TMR0                    ;DER FESTE RAM-SPEICHER (TMR0) WIRD MIT 61 GELADEN
                        BCF     INTCON, T0IF            ;OVERFLOW = 0
                
T102                    BTFSS   INTCON, T0IF            ;WENN DIE ZEIT VON 10MSEC ABGELAUFEN IST, WIRD T0IF HIGH (1) UND 
                        GOTO    T102                    ;ES ERFOLGT EIN SPRUNG ZU "DECFSC MERK, F"
                        
                        DECFSZ  HELP2, F
                        GOTO    T101

                        DECFSZ  HELP1, F                ;ES WIRD DER WERT IN "HELP1" ABWRTS GEZHLT, BIS ER (0) IST UND
                        GOTO    T100                    ;DANN ERFOLGT EIN SPRUNG ZU "RETURN"-ENDE DES UNTERPROGRAMMS

                        RETURN

;ZEITBERECHNUNG FUER 50MSEC
;PRESCALER 256X  *  SYSTEM 4X  * TAKTZEIT ====> 256*4*0.250SEC=256SEC    /DIE TAKTZEIT ERGIBT SICH AUS DEM INTERNEN OSZILLATOR
;50MSEC : 256SEC= 195,3 GENOMMEN 195                                      /T = 1 : F  (F)-OSZILLATORFREQUENZ
;ALSO
;256S*D'195'=49,92MSEC
;TMR0 ALSO D'256'-D'195'=D'61' ENTSPRICHT CA. 50MS
;61 DEZIMAL OBEN EINTRAGEN

;*****************************************************************************
;*         UNTERPROGRAMM MIT TIMER0 ALS ZEITSCHLEIFE FUER  10MSEC ....       *
;*                                                                           *
;*****************************************************************************
ZS10MS                  MOVWF   HELP1                   ;DER INHALT VON W WIRD IN "HELP1" GELADEN

T1010                   MOVLW   D'217'
                        MOVWF   TMR0                    
                        BCF     INTCON, T0IF            ;OVERFLOW = 0
                
T1020                   BTFSS   INTCON, T0IF            
                        GOTO    T1020                   

                        DECFSZ  HELP1, F                
                        GOTO    T1010                   

                        RETURN

;ZEITBERECHNUNG FUER 10MSEC
;PRESCALER 256X  *  SYSTEM 4X  * TAKTZEIT ====> 256*4*0.250SEC=256SEC    /DIE TAKTZEIT ERGIBT SICH AUS DEM INTERNEN OSZILLATOR
;10MSEC : 256SEC= 39,06 GENOMMEN 39                                       /T = 1 : F  (F)-OSZILLATORFREQUENZ
;ALSO
;256S*D'39'=9,98MSEC
;TMR0 ALSO D'256'-D'39'=D'217' ENTSPRICHT CA. 10MS
;217 DEZIMAL OBEN EINTRAGEN

;*****************************************************************************
;*                              INIT TIMER1 500MSEC                          *
;*                                                                           *
;*****************************************************************************
        
I_ZS500MS   BCF     T1CON, TMR1ON       ;STOP TIMER1
            MOVLW   0X0B                
            MOVWF   TMR1H               
            MOVLW   0XDC
            MOVWF   TMR1L
            BCF     PIR1, TMR1IF        ;OVERFLOW 0 MACHEN
            BSF     T1CON, TMR1ON       ;START TIMER1
            RETURN


;TIMER1:
;32 * 0.250SEC = 8SEC
;500MSEC : 8SEC = 62.500
;65536 (0X10000) - 62500 = 3036 IN HEX.0X0BDC
;BEI TMR1H 0X0B EINTRAGEN BERECHNET
;BEI TMR1L 0XDC EINTRAGEN BERECHNET

;*****************************************************************************
;*                              DATEN AUSGEBEN AUF DOT-LCD-MODUL             *
;*                              04.05.10                                     *
;*****************************************************************************
DATEN       BSF     PORTA, RS               ;ALS DATEN

            MOVWF   BIT

            MOVF    PORTB, W
            ANDLW   0X0F
            MOVWF   MERK

            MOVF    BIT, W
            ANDLW   0XF0
            ADDWF   MERK, W
            MOVWF   PORTB


            BSF     PORTA, EN

;ZEITSCHLEIFE 4SEC
            MOVLW   D'1'                    ;UNGEFAEHR 4SEC ZEITSCHLEIFE
            MOVWF   HELP1
D1          NOP                             ;T=4
            DECFSZ  HELP1, F                ;T=4
            GOTO    D1                      ;T=8    GES.:16TAKTE * 0,250SEC= 4SEC    *1 DURCHLAEUFE= 4SEC
;ENDE ZEITSCHLEIFE
 
            BCF     PORTA, EN

;---------------------------------

;LOW 4BIT AUSGEBEN
            RLF     BIT, F
            RLF     BIT, F
            RLF     BIT, F
            RLF     BIT, F

            MOVF    PORTB, W
            ANDLW   0X0F
            MOVWF   MERK

            MOVF    BIT, W
            ANDLW   0XF0
            ADDWF   MERK, W
            MOVWF   PORTB


            BSF     PORTA, EN

;ZEITSCHLEIFE 4SEC
            MOVLW   D'1'                    
            MOVWF   HELP1
DDD1        NOP                             
            DECFSZ  HELP1, F                
            GOTO    DDD1                    
;ENDE ZEITSCHLEIFE
 
            BCF     PORTA, EN

;ZEITSCHLEIFE 40SEC
            MOVLW   D'10'                   ;UNGEFAEHR 40SEC ZEITSCHLEIFE
            MOVWF   HELP1
DDDD1       NOP
            DECFSZ  HELP1, F                ;WIE OBEN  GES.:16TAKTE * 0,250SEC= 4SEC    * 10 DURCHLAEUFE= 40SEC
            GOTO    DDDD1
;ENDE ZEITSCHLEIFE



            RETURN

;*****************************************************************************
;*                              BEFEHL AUSGEBEN AUF DOT-LCD-MODUL            *
;*                              04.05.10                                     *
;*****************************************************************************
BEFEHL      BCF     PORTA, RS                ;ALS BEFEHL

            MOVWF   BIT

            MOVF    PORTB, W
            ANDLW   0X0F
            MOVWF   MERK

            MOVF    BIT, W
            ANDLW   0XF0
            ADDWF   MERK, W
            MOVWF   PORTB

            BSF     PORTA, EN

;ZEITSCHLEIFE 4SEC
            MOVLW   D'1'                    ;UNGEFAEHR 8SEC ZEITSCHLEIFE
            MOVWF   HELP1
B1          NOP                             ;T=4
            DECFSZ  HELP1, F                ;T=4
            GOTO    B1                      ;T=8        GES.:16TAKTE * 0,250SEC= 4SEC    *1 DURCHLAEUFE= 4SEC
;ENDE ZEITSCHLEIFE
 
            BCF     PORTA, EN

;---------------------------------

;LOW 4BIT AUSGEBEN
            RLF     BIT, F
            RLF     BIT, F
            RLF     BIT, F
            RLF     BIT, F

            MOVF    PORTB, W
            ANDLW   0X0F
            MOVWF   MERK

            MOVF    BIT, W
            ANDLW   0XF0
            ADDWF   MERK, W
            MOVWF   PORTB

            BSF     PORTA, EN

;ZEITSCHLEIFE 8SEC
            MOVLW   D'1'                    
            MOVWF   HELP1
BBB1        NOP                             
            DECFSZ  HELP1, F                
            GOTO    BBB1                    
;ENDE ZEITSCHLEIFE
 
            BCF     PORTA, EN

;ZEITSCHLEIFE 40SEC
            MOVLW   D'10'                   ;UNGEFAEHR 80SEC ZEITSCHLEIFE
            MOVWF   HELP1
BBBB1       NOP
            DECFSZ  HELP1, F                ;WIE OBEN  GES.:16TAKTE * 0,250SEC= 4SEC    * 10 DURCHLAEUFE=40SEC
            GOTO    BBBB1
;ENDE ZEITSCHLEIFE
 
            RETURN


;*****************************************************************************
;*                              TEXT "GEHT GLEICH LOS"                       *
;*                                                                           *
;*****************************************************************************
GEHT        MOVLW   H'80' 
            CALL    BEFEHL
            MOVLW   "G"
            CALL    DATEN

            MOVLW   H'81' 
            CALL    BEFEHL
            MOVLW   "E"
            CALL    DATEN

            MOVLW   H'82' 
            CALL    BEFEHL
            MOVLW   "H"
            CALL    DATEN

            MOVLW   H'83' 
            CALL    BEFEHL
            MOVLW   "T"
            CALL    DATEN

            MOVLW   H'84' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'85' 
            CALL    BEFEHL
            MOVLW   "G"
            CALL    DATEN

            MOVLW   H'86' 
            CALL    BEFEHL
            MOVLW   "L"
            CALL    DATEN

            MOVLW   H'87' 
            CALL    BEFEHL
            MOVLW   "E"
            CALL    DATEN

            MOVLW   H'88' 
            CALL    BEFEHL
            MOVLW   "I"
            CALL    DATEN

            MOVLW   H'89' 
            CALL    BEFEHL
            MOVLW   "C"
            CALL    DATEN

            MOVLW   H'8A' 
            CALL    BEFEHL
            MOVLW   "H"
            CALL    DATEN

            MOVLW   H'8B' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'8C' 
            CALL    BEFEHL
            MOVLW   "L"
            CALL    DATEN

            MOVLW   H'8D' 
            CALL    BEFEHL
            MOVLW   "O"
            CALL    DATEN

            MOVLW   H'8E' 
            CALL    BEFEHL
            MOVLW   "S"
            CALL    DATEN

            MOVLW   H'8F' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

;----------------
            MOVLW   H'C0' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'C1' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'C2' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'C3' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'C4' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'C5' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'C6' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'C7' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'C8' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'C9' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'CA' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'CB' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'CC' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'CD' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'CE' 
            CALL    BEFEHL
            MOVLW   "="
            CALL    DATEN

            MOVLW   H'CF' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

;5SEC ZEITSCHLEIFE
            MOVLW   D'50'                  ;ZEITSCHLEIFE LADEN IN W MIT DEZIMAL 50 ALSO---> 50*100MSEC=5000MSEC=5SEC
            CALL    ZS100MS
            RETURN


;*****************************************************************************
;*                              TEXT "Zeit-Einstellen  "                       *
;*                                                                           *
;*****************************************************************************
EINST       MOVLW   H'80' 
            CALL    BEFEHL
            MOVLW   "Z"
            CALL    DATEN

            MOVLW   H'81' 
            CALL    BEFEHL
            MOVLW   "e"
            CALL    DATEN

            MOVLW   H'82' 
            CALL    BEFEHL
            MOVLW   "i"
            CALL    DATEN

            MOVLW   H'83' 
            CALL    BEFEHL
            MOVLW   "t"
            CALL    DATEN

            MOVLW   H'84' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'85' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'86' 
            CALL    BEFEHL
            MOVLW   "E"
            CALL    DATEN

            MOVLW   H'87' 
            CALL    BEFEHL
            MOVLW   "i"
            CALL    DATEN

            MOVLW   H'88' 
            CALL    BEFEHL
            MOVLW   "n"
            CALL    DATEN

            MOVLW   H'89' 
            CALL    BEFEHL
            MOVLW   "s"
            CALL    DATEN

            MOVLW   H'8A' 
            CALL    BEFEHL
            MOVLW   "t"
            CALL    DATEN

            MOVLW   H'8B' 
            CALL    BEFEHL
            MOVLW   "e"
            CALL    DATEN

            MOVLW   H'8C' 
            CALL    BEFEHL
            MOVLW   "l"
            CALL    DATEN

            MOVLW   H'8D' 
            CALL    BEFEHL
            MOVLW   "l"
            CALL    DATEN

            MOVLW   H'8E' 
            CALL    BEFEHL
            MOVLW   "e"
            CALL    DATEN

            MOVLW   H'8F' 
            CALL    BEFEHL
            MOVLW   "n"
            CALL    DATEN

            RETURN

;*****************************************************************************
;*                              TEXT "   Zeit-Luft   "                      *
;*                                                                           *
;*****************************************************************************
BACK        MOVLW   H'80' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'81' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'82' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'83' 
            CALL    BEFEHL
            MOVLW   "Z"
            CALL    DATEN

            MOVLW   H'84' 
            CALL    BEFEHL
            MOVLW   "e"
            CALL    DATEN

            MOVLW   H'85' 
            CALL    BEFEHL
            MOVLW   "i"
            CALL    DATEN

            MOVLW   H'86' 
            CALL    BEFEHL
            MOVLW   "t"
            CALL    DATEN

            MOVLW   H'87' 
            CALL    BEFEHL
            MOVLW   "-"
            CALL    DATEN

            MOVLW   H'88' 
            CALL    BEFEHL
            MOVLW   "L"
            CALL    DATEN

            MOVLW   H'89' 
            CALL    BEFEHL
            MOVLW   B'11100001'
            CALL    DATEN

            MOVLW   H'8A' 
            CALL    BEFEHL
            MOVLW   "u"
            CALL    DATEN

            MOVLW   H'8B' 
            CALL    BEFEHL
            MOVLW   "f"
            CALL    DATEN

            MOVLW   H'8C' 
            CALL    BEFEHL
            MOVLW   "t"
            CALL    DATEN

            MOVLW   H'8D' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'8E' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'8F' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            RETURN

;*****************************************************************************
;*                              TEXT "  Zeit zu Ende  "                      *
;*                                                                           *
;*****************************************************************************
ENDE        MOVLW   H'80' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'81' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'82' 
            CALL    BEFEHL
            MOVLW   "Z"
            CALL    DATEN

            MOVLW   H'83' 
            CALL    BEFEHL
            MOVLW   "e"
            CALL    DATEN

            MOVLW   H'84' 
            CALL    BEFEHL
            MOVLW   "i"
            CALL    DATEN

            MOVLW   H'85' 
            CALL    BEFEHL
            MOVLW   "t"
            CALL    DATEN

            MOVLW   H'86' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'87' 
            CALL    BEFEHL
            MOVLW   "z"
            CALL    DATEN

            MOVLW   H'88' 
            CALL    BEFEHL
            MOVLW   "u"
            CALL    DATEN

            MOVLW   H'89' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'8A' 
            CALL    BEFEHL
            MOVLW   "E"
            CALL    DATEN

            MOVLW   H'8B' 
            CALL    BEFEHL
            MOVLW   "n"
            CALL    DATEN

            MOVLW   H'8C' 
            CALL    BEFEHL
            MOVLW   "d"
            CALL    DATEN

            MOVLW   H'8D' 
            CALL    BEFEHL
            MOVLW   "e"
            CALL    DATEN

            MOVLW   H'8E' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'8F' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            RETURN


;*****************************************************************************
;*                              TEXT "MIN + SEC"                             *
;*                                                                           *
;*****************************************************************************
ZEIT        MOVLW   H'C0' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'C1' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'C2' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'C3' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'C4' 
            CALL    BEFEHL
            MOVLW   "M"
            CALL    DATEN

            MOVLW   H'C5' 
            CALL    BEFEHL
            MOVLW   "I"
            CALL    DATEN

            MOVLW   H'C6' 
            CALL    BEFEHL
            MOVLW   "N"
            CALL    DATEN

            MOVLW   H'C7' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'C8' 
            CALL    BEFEHL
            MOVLW   ":"
            CALL    DATEN

            MOVLW   H'C9' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'CA' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'CB' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'CC' 
            CALL    BEFEHL
            MOVLW   " "
            CALL    DATEN

            MOVLW   H'CD' 
            CALL    BEFEHL
            MOVLW   "S"
            CALL    DATEN

            MOVLW   H'CE' 
            CALL    BEFEHL
            MOVLW   "E"
            CALL    DATEN

            MOVLW   H'CF' 
            CALL    BEFEHL
            MOVLW   "C"
            CALL    DATEN

            RETURN  



            END





